CCSDSPy - IO Interface for Reading CCSDS Data in Python.
========================================================

.. image:: https://github.com/ddasilva/ccsdspy/actions/workflows/ccsdspy-ci.yml/badge.svg
    :target: https://github.com/ddasilva/ccsdspy/actions
    :alt: CI Status
          
This package provides a Python interface for reading tightly packed bits in the CCSDS format used for many NASA and ESA missions.
 
